@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: filesystem.py 986 2006-06-24 19:23:22Z pronovic $
+# Revision : $Id: filesystem.py 1012 2006-12-18 23:52:27Z pronovic $
 # Purpose  : Provides filesystem-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -905,6 +905,13 @@ class BackupFileList(FilesystemList):
                   raise tarfile.TarError(e)
                logger.info("Unable to add file [%s]; going on anyway." % entry)
          tar.close()
+      except tarfile.ReadError, e:
+         try: tar.close()
+         except: pass
+         if os.path.exists(path): 
+            try: os.remove(path) 
+            except: pass
+         raise tarfile.ReadError("Unable to open [%s]; maybe directory doesn't exist?" % path)
       except tarfile.TarError, e:
          try: tar.close()
          except: pass
