@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1002 2006-09-04 18:48:13Z pronovic $
+# Revision : $Id: release.py 1022 2006-12-19 04:53:11Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici, et. al"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2006"
-VERSION     = "2.8.1"
-DATE        = "04 Sep 2006"
+VERSION     = "2.9.0"
+DATE        = "18 Dec 2006"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
